@@ -32,7 +32,7 @@ from spyder.config.manager import CONF
 from spyder.py3compat import (builtins, is_string, is_text_string,
                               PY3, str_lower, to_text_string)
 from spyder.utils import encoding
-from spyder.utils import icon_manager as ima
+from spyder.utils.icon_manager import ima
 from spyder.utils.qthelpers import (add_actions, create_action, keybinding,
                                     restore_keyevent)
 from spyder.widgets.mixins import (GetHelpMixin, SaveHistoryMixin,
@@ -40,16 +40,20 @@ from spyder.widgets.mixins import (GetHelpMixin, SaveHistoryMixin,
 from spyder.plugins.console.widgets.console import ConsoleBaseWidget
 
 
+# Maximum number of lines to load
+MAX_LINES = 1000
+
+
 class ShellBaseWidget(ConsoleBaseWidget, SaveHistoryMixin,
                       BrowseHistoryMixin):
     """
     Shell base widget
     """
 
-    redirect_stdio = Signal(bool)
+    sig_redirect_stdio_requested = Signal(bool)
     sig_keyboard_interrupt = Signal()
     execute = Signal(str)
-    append_to_history = Signal(str, str)
+    sig_append_to_history_requested = Signal(str, str)
 
     def __init__(self, parent, history_filename, profile=False,
                  initial_message=None, default_foreground_color=None,
@@ -255,10 +259,10 @@ class ShellBaseWidget(ConsoleBaseWidget, SaveHistoryMixin,
     def save_historylog(self):
         """Save current history log (all text in console)"""
         title = _("Save history log")
-        self.redirect_stdio.emit(False)
+        self.sig_redirect_stdio_requested.emit(False)
         filename, _selfilter = getsavefilename(self, title,
                     self.historylog_filename, "%s (*.log)" % _("History logs"))
-        self.redirect_stdio.emit(True)
+        self.sig_redirect_stdio_requested.emit(True)
         if filename:
             filename = osp.normpath(filename)
             try:
@@ -504,7 +508,7 @@ class ShellBaseWidget(ConsoleBaseWidget, SaveHistoryMixin,
                    if line and not line.startswith('#')]
 
         # Truncating history to X entries:
-        while len(history) >= CONF.get('historylog', 'max_entries'):
+        while len(history) >= MAX_LINES:
             del history[0]
             while rawhistory[0].startswith('#'):
                 del rawhistory[0]
@@ -640,7 +644,22 @@ class PythonShellWidget(TracebackLinksMixin, ShellBaseWidget,
     INITHISTORY = ['# -*- coding: utf-8 -*-',
                    '# *** Spyder Python Console History Log ***',]
     SEPARATOR = '%s##---(%s)---' % (os.linesep*2, time.ctime())
-    go_to_error = Signal(str)
+
+    # --- Signals
+    # This signal emits a parsed error traceback text so we can then
+    # request opening the file that traceback comes from in the Editor.
+    sig_go_to_error_requested = Signal(str)
+
+    # Signal
+    sig_help_requested = Signal(dict)
+    """
+    This signal is emitted to request help on a given object `name`.
+
+    Parameters
+    ----------
+    help_data: dict
+        Example `{'name': str, 'ignore_unknown': bool}`.
+    """
 
     def __init__(self, parent, history_filename, profile=False, initial_message=None):
         ShellBaseWidget.__init__(self, parent, history_filename,
@@ -744,9 +763,6 @@ class PythonShellWidget(TracebackLinksMixin, ShellBaseWidget,
     def postprocess_keyevent(self, event):
         """Process keypress event"""
         ShellBaseWidget.postprocess_keyevent(self, event)
-        if QToolTip.isVisible():
-            _event, _text, key, _ctrl, _shift = restore_keyevent(event)
-            self.hide_tooltip_if_necessary(key)
 
     def _key_other(self, text):
         """1 character key"""
@@ -851,27 +867,35 @@ class PythonShellWidget(TracebackLinksMixin, ShellBaseWidget,
     def get_dir(self, objtxt):
         """Return dir(object)"""
         raise NotImplementedError
+
     def get_globals_keys(self):
         """Return shell globals() keys"""
         raise NotImplementedError
+
     def get_cdlistdir(self):
         """Return shell current directory list dir"""
         raise NotImplementedError
+
     def iscallable(self, objtxt):
         """Is object callable?"""
         raise NotImplementedError
+
     def get_arglist(self, objtxt):
         """Get func/method argument list"""
         raise NotImplementedError
+
     def get__doc__(self, objtxt):
         """Get object __doc__"""
         raise NotImplementedError
+
     def get_doc(self, objtxt):
         """Get object documentation dictionary"""
         raise NotImplementedError
+
     def get_source(self, objtxt):
         """Get object source"""
         raise NotImplementedError
+
     def is_defined(self, objtxt, force_import=False):
         """Return True if object is defined"""
         raise NotImplementedError
@@ -975,7 +999,10 @@ class TerminalWidget(ShellBaseWidget):
     COM = 'rem' if os.name == 'nt' else '#'
     INITHISTORY = ['%s *** Spyder Terminal History Log ***' % COM, COM,]
     SEPARATOR = '%s%s ---(%s)---' % (os.linesep*2, COM, time.ctime())
-    go_to_error = Signal(str)
+
+    # This signal emits a parsed error traceback text so we can then
+    # request opening the file that traceback comes from in the Editor.
+    sig_go_to_error_requested = Signal(str)
 
     def __init__(self, parent, history_filename, profile=False):
         ShellBaseWidget.__init__(self, parent, history_filename, profile)
